minimalStyle constant

SmartNavStyle const minimalStyle

A minimal style with transparent background and simple elements. Features no background or borders, with basic animations and hidden labels.

Implementation

static const SmartNavStyle minimalStyle = SmartNavStyle(
  backgroundColor: Colors.white,
  borderColor: Colors.transparent,
  borderRadius: 0,
  margin: EdgeInsets.zero,
  padding: EdgeInsets.symmetric(vertical: 8),
  defaultActiveColor: Colors.blueAccent,
  defaultInactiveColor: Colors.grey,
  defaultActiveTextStyle: TextStyle(
    fontSize: 12,
    fontWeight: FontWeight.w600,
  ),
  defaultInactiveTextStyle: TextStyle(
    fontSize: 12,
    color: Color(0xFFCCCCCC),
    fontWeight: FontWeight.w400,
  ),
  defaultIconSize: 24.0,
  scaleFactor: 1.0,
  animationCurve: Curves.easeOutQuad,
  animationDuration: Duration(milliseconds: 300),
  showLabel: false,
);